@@ -3,9 +3,9 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "dyndb-config.h"
 #else
-#error "Can't compile without config.h"
+#error "Can't compile without dyndb-config.h"
 #endif
 
 #include <isc/buffer.h>
@@ -54,7 +54,9 @@
 
 #if LIBDNS_VERSION_MAJOR < 1600
 typedef dns_name_t       node_name_t;
+#define REFCOUNT_FLOOR 0
 #else
+#define REFCOUNT_FLOOR 1
 typedef const dns_name_t node_name_t;
 #endif
 
@@ -195,7 +197,7 @@ detach(dns_db_t **dbp)
 	refs = isc_refcount_decrement(&ldapdb->refs);
 #endif
 
-	if (refs == 1) {
+	if (refs == REFCOUNT_FLOOR) {
 		free_ldapdb(ldapdb);
 	}
 }
@@ -957,6 +959,10 @@ static dns_dbmethods_t ldapdb_methods = {
 	setservestalettl,
 	getservestalettl,
 #endif
+#if LIBDNS_VERSION_MAJOR >= 1609
+	NULL, /* setservestalerefresh */
+	NULL, /* getservestalerefresh */
+#endif
 #if LIBDNS_VERSION_MAJOR >= 1600
 	NULL, /* setgluecachestats */
 #endif
