@@ -12,6 +12,7 @@
 #include <dns/result.h>
 #include <dns/zone.h>
 
+#include "config.h"
 #include "fs.h"
 #include "ldap_driver.h"
 #include "log.h"
@@ -111,11 +112,16 @@ zr_create(isc_mem_t *mctx, ldap_instance_t *ldap_inst,
 	REQUIRE(glob_settings != NULL);
 	REQUIRE(zrp != NULL && *zrp == NULL);
 
-	CHECKED_MEM_GET_PTR(mctx, zr);
+	zr = isc_mem_get(mctx, sizeof(*(zr)));
 	ZERO_PTR(zr);
 	isc_mem_attach(mctx, &zr->mctx);
 	CHECK(dns_rbt_create(mctx, delete_zone_info, mctx, &zr->rbt));
+#if LIBDNS_VERSION_MAJOR >= 1600
+	/* Never fails on BIND 9.16, even it if returns value */
+	(void)isc_rwlock_init(&zr->rwlock, 0, 0);
+#else
 	CHECK(isc_rwlock_init(&zr->rwlock, 0, 0));
+#endif
 	zr->global_settings = glob_settings;
 	zr->ldap_inst = ldap_inst;
 
@@ -123,11 +129,10 @@ zr_create(isc_mem_t *mctx, ldap_instance_t *ldap_inst,
 	return ISC_R_SUCCESS;
 
 cleanup:
-	if (zr != NULL) {
-		if (zr->rbt != NULL)
-			dns_rbt_destroy(&zr->rbt);
-		MEM_PUT_AND_DETACH(zr);
+	if (zr->rbt != NULL) {
+		dns_rbt_destroy(&zr->rbt);
 	}
+	MEM_PUT_AND_DETACH(zr);
 
 	return result;
 }
@@ -272,17 +277,17 @@ create_zone_info(isc_mem_t * const mctx, dns_zone_t * const raw,
 	REQUIRE(dn != NULL);
 	REQUIRE(zinfop != NULL && *zinfop == NULL);
 
-	CHECKED_MEM_GET_PTR(mctx, zinfo);
+	zinfo = isc_mem_get(mctx, sizeof(*(zinfo)));
 	ZERO_PTR(zinfo);
-	CHECKED_MEM_STRDUP(mctx, dn, zinfo->dn);
+	zinfo->dn = isc_mem_strdup(mctx, dn);
 	dns_zone_attach(raw, &zinfo->raw);
 	if (secure != NULL)
 		dns_zone_attach(secure, &zinfo->secure);
 
 	zinfo->settings = NULL;
-	isc_string_printf_truncate(settings_name, PRINT_BUFF_SIZE,
-				   SETTING_SET_NAME_ZONE " %s",
-				   dn);
+	/* truncation is allowed */
+	snprintf(settings_name, PRINT_BUFF_SIZE, SETTING_SET_NAME_ZONE " %s",
+		 dn);
 	CHECK(settings_set_create(mctx, zone_settings, sizeof(zone_settings),
 				  settings_name, global_settings,
 				  &zinfo->settings));
@@ -341,7 +346,9 @@ delete_zone_info(void *arg1, void *arg2)
  * @pre Zone registed is locked.
  */
 static isc_result_t
-getzinfo(zone_register_t * const zr, dns_name_t *name, zone_info_t **zinfo) {
+getzinfo(zone_register_t * const zr, const dns_name_t *name,
+	 zone_info_t **zinfo)
+{
 	isc_result_t result;
 	void *data = NULL;
 
@@ -438,8 +445,8 @@ cleanup:
  * Either ldapdbp or rbtdbp can be NULL.
  */
 isc_result_t
-zr_get_zone_dbs(zone_register_t *zr, dns_name_t *name, dns_db_t **ldapdbp,
-		dns_db_t **rbtdbp)
+zr_get_zone_dbs(zone_register_t *zr, const dns_name_t *name,
+		dns_db_t **ldapdbp, dns_db_t **rbtdbp)
 {
 	isc_result_t result;
 	zone_info_t *zinfo = NULL;
@@ -539,7 +546,8 @@ zr_get_zone_ptr(zone_register_t * const zr, dns_name_t * const name,
  * 'set'.
  */
 isc_result_t
-zr_get_zone_settings(zone_register_t *zr, dns_name_t *name, settings_set_t **set)
+zr_get_zone_settings(zone_register_t *zr, const dns_name_t *name,
+	             settings_set_t **set)
 {
 	isc_result_t result;
 	zone_info_t *zinfo = NULL;
